==> integration_agence-ultramedia_20170122_0525.tgz: var/www/vhosts/integration.agence-ultramedia.com/htdocs/wp-content/themes/emag_new/header.php <==
<!DOCTYPE html>

<html  lang="fr" xml:lang="fr" class="full no-js">
    <head>
<style>
/**
 * name:        FancyBox Transitions
 * file:        jquery.fancybox-transitions.css
 * version:     0.1
 * author:      Thomas Lagier
 * description: Adds CSS3 open/close transitions for FancyBox 2.
 * license:     MIT
 * date:        April 25, 2014
 */

/* Effect 1: Fade in and scale up */
/*.fadescale{
    -webkit-transform: scale(0.7);
    -moz-transform: scale(0.7);
    -ms-transform: scale(0.7);
    transform: scale(0.7);
    opacity: 0;
}

.fadescale-transitions{
    -webkit-transition: all 0.3s;
    -moz-transition: all 0.3s;
    transition: all 0.3s;
}

.fadescale.show{
    -webkit-transform: scale(1);
    -moz-transform: scale(1);
    -ms-transform: scale(1);
    transform: scale(1);
    opacity: 1;
}*/

.ico_link_defaut{

}

.ico_link_chiffres_cles{
    background-position: -300px -120px!important;
}
.ico_link_chiffres_cles:hover{
    background-position: -300px -180px!important;
}

.ico_link_citation{
    background-position: 0 -120px!important;
}
.ico_link_citation:hover{
    background-position: 0 -180px!important;
}


.ico_link_embed{
    background-position: -420px -120px!important;
}
.ico_link_embed:hover{
    background-position: -420px -180px!important;
}

.ico_link_galerie{
    background-position: -300px -360px!important;
}
.ico_link_galerie:hover{
    background-position: -300px -420px!important;
}

</style>
        <meta charset="<?php bloginfo('charset'); ?>">
        <title><?php wp_title(''); ?><?php
            if (wp_title('', false)) {
                echo ' :';
            }
            ?> <?php bloginfo('name'); ?></title>

        <link href="<?php bloginfo('url'); ?>favicon.ico" rel="shortcut icon">
        <link href="<?php echo get_template_directory_uri(); ?>/img/icons/touch.png" rel="apple-touch-icon-precomposed">
        <meta http-equiv="X-UA-Compatible" content="IE=edge">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <meta name="description" content="<?php bloginfo('description'); ?>">

        <link rel="stylesheet" type="text/css" href="<?php echo get_template_directory_uri(); ?>/css/bootstrap.css">
        <link rel="stylesheet" type="text/css" href="<?php echo get_template_directory_uri(); ?>/css/bootstrap-theme.css">
        <link rel="stylesheet" type="text/css" href="<?php echo get_template_directory_uri(); ?>/css/portfolio.css">
        <link rel="stylesheet" type="text/css" href="<?php echo get_template_directory_uri(); ?>/css/site.css">
        <link rel="stylesheet" type="text/css" href="<?php echo get_template_directory_uri(); ?>/css/jquery.cookiebar.css">

        <?php wp_head(); ?>

		<script type="text/javascript" src="<?php echo get_template_directory_uri(); ?>/js/jquery.cookiebar.js"></script>
		<script type="text/javascript">
			jQuery(document).ready(function(){
				jQuery.cookieBar({
				declineButton: false,
				bottom: false,
				});
			});
		</script>


        
        <script>
            // conditionizr.com
            // configure environment tests
            conditionizr.config({
                assets: '<?php echo get_template_directory_uri(); ?>',
                tests: {}
            });</script>
        <?php echo GenererFichiersCSS(); ?>
    </head>
    <body <?php body_class(); ?>>
<!-- AJOUT -->
	<dep49-header></dep49-header>
<!-- fin ajout -->
        <?php
        $current_numero = getCurrentNumero();
        $num_colors = get_option('numero_colors');
        $active_color = $num_colors[$current_numero->term_id];
        $bg = get_field("image_de_couverture", $current_numero->id_acf);
        $bg_cat = get_field("image_de_fond", "category_" . the_category_ID(false));
        $item = get_post($link["ID"]);
        $post_format = get_post_format($link["ID"]);
        $numMag = get_field("numerotation", $current_numero->id_acf);
//        get("coucou");
        if (!empty($bg_cat) && !is_home()) {
            // vars
            $bg_img = $bg_cat['url'];
            $bg_title = $bg_cat['alt'];
        } else {
            $bg_img = $bg['url'];
            $bg_title = $bg['alt'];
        }
//        if ($post_format == "aside" && !is_category()) {
//            $bg_cat = wp_get_attachment_image_src(get_post_thumbnail_id ( $post_ID ), 'full');
//            $bg_img = $bg_cat[0];
//
//        }

        $fonts = get_field("police", $current_numero->id_acf);
        //FONT TITLE
        if ($fonts) {
            wp_enqueue_style("dh_options_typography", "http://fonts.googleapis.com/css?family=$fonts", false, null, 'all');
            $fonts_css = "body, td, div, a, form, input, textarea, p{font-family:" . $fonts . " !important;}";
        }
        $fonts_title = get_field("police_titre", $current_numero->id_acf);
        if ($fonts_title) {
            wp_enqueue_style("dh_options_typography_title", "http://fonts.googleapis.com/css?family=$fonts_title", false, null, 'all');
            $fonts_css_title = ".home h2 p, .single h1.post-title, .page h2.color-current-numero, h1.category_color, h1.color-current-numero-bg, .encadre-titre h2, .h4.color-current-numero{font-family:" . $fonts_title . " !important;}";
        }
        ?>

        <style scoped>
            body{
                background: url(<?php echo $bg_img; ?>) no-repeat center fixed;
                -webkit-background-size: cover !important;
                background-size: cover !important;
                background-position: 0 50px !important;
            }
            <?php echo $fonts_css; ?>
            <?php echo $fonts_css_title; ?>
            nav.navbar{
                background-color:<?php echo $active_color; ?>;
            }
            span.count{
                background-color:<?php echo $active_color; ?>;
            }

            .color-current-numero{
                color: <?php echo $active_color; ?> !important;
            }
            .color-current-numero-bg{
                background-color: <?php echo $active_color; ?> !important;
            }
        </style>

        <?php
        // Get Arbo
        $tree_menu = dh_get_tree_menu_nav();

        // Get id current
        if (is_single()) {
            $id_item = get_the_ID(false);
        } else {
            $id_item = the_category_ID(false);
        }
        if (is_page()) {
            $id_item = $post->ID;
        }
        if (is_front_page()) {
            $id_item = 0;
        }

        // Set link
        if (!empty($tree_menu)) {
            $key = dh_find_key_array_by_value($tree_menu, $id_item);
            $max = count($tree_menu);
            
            $prev = $key - 1;
            if ($prev < 0) {
                $prev = $max - 1;
            }

            $next = $key + 1;
            if ($next > ($max - 1)) {
                $next = 0;
            }

            $link_prev = $tree_menu[$prev]['url'];
            $link_current = $tree_menu[$key]['url'];
            $link_next = $tree_menu[$next]['url'];
        }
        ?>
        <header>
            <nav class="navbar navbar-inverse navbar-static-top" role="navigation">
                <div class="navbar-header">
                    <button type="button" class="navbar-toggle collapsed pull-left" data-toggle="collapse" data-target="#main-navigation">
                        <span class="sr-only">Toggle navigation</span>
                        <span class="icon-bar"></span>
                        <span class="icon-bar"></span>
                        <span class="icon-bar"></span>
                    </button>
                </div>
                <div class="collapse navbar-collapse " id="main-navigation">
                    <?php wp_nav_menu(array('theme_location' => 'header-menu')); ?>
                </div>

                <div id="lang-navigation">
                    <?php wp_nav_menu(array('theme_location' => 'langmenu')); ?>
                </div>
            </nav>
        </header>
        <a href="#"><i class='ico-hide-menu' style="background-color:<?php echo $active_color; ?>" alt="Déplier/Replier le menu" title="Déplier/Replier le menu"></i></a>

        <div class="container-fluid">
            <div id="subnav" class="row">
                <ul class="ico-menu">
                    <li><?php get_template_part('searchform'); ?></li>
                    <li <?php
                    if (is_home() || is_front_page()) {
                        echo "style='border-bottom:5px solid " . $active_color . ";'";
                    };
                    ?> ><a href="<?php echo get_site_url(); ?>" class="ico-home" alt="home"></a></li>
                    <li><div class="ico-sommaire"><a href="<?php echo get_permalink(290); ?>">Sommaire</a></div></li>
                </ul>
                <div style="position:relative;overflow:hidden;width:960px;" class="container-scroll">
                    <?php wp_nav_menu(array('menu' => 'Sous-menu-' . $numMag)); ?>
                </div>
                <div class="scrollers">
                    <a tabindex="-1" class="fastclick back" href="#b" alt="Retour">Retour</a>
                    <a tabindex="-1" class="fastclick forward" href="#f" alt="En avant">En avant</a>
                </div>
            </div>
            <?php echo do_shortcode("[DH_SOCIAL_SHARE prev=" . $link_prev . " current=" . $link_current . " next=" . $link_next . "]"); ?>
        </div>

        <div class="container-fluid stop-fluid wrap-page" title="<?php echo $bg_title; ?>" >

==> integration_agence-ultramedia_20170129_0525.tgz: var/www/vhosts/integration.agence-ultramedia.com/htdocs/wp-content/themes/emag_new/header.php <==
<!DOCTYPE html>

<html  lang="fr" xml:lang="fr" class="full no-js">
    <head>
<style>
/**
 * name:        FancyBox Transitions
 * file:        jquery.fancybox-transitions.css
 * version:     0.1
 * author:      Thomas Lagier
 * description: Adds CSS3 open/close transitions for FancyBox 2.
 * license:     MIT
 * date:        April 25, 2014
 */

/* Effect 1: Fade in and scale up */
/*.fadescale{
    -webkit-transform: scale(0.7);
    -moz-transform: scale(0.7);
    -ms-transform: scale(0.7);
    transform: scale(0.7);
    opacity: 0;
}

.fadescale-transitions{
    -webkit-transition: all 0.3s;
    -moz-transition: all 0.3s;
    transition: all 0.3s;
}

.fadescale.show{
    -webkit-transform: scale(1);
    -moz-transform: scale(1);
    -ms-transform: scale(1);
    transform: scale(1);
    opacity: 1;
}*/

.ico_link_defaut{

}

.ico_link_chiffres_cles{
    background-position: -300px -120px!important;
}
.ico_link_chiffres_cles:hover{
    background-position: -300px -180px!important;
}

.ico_link_citation{
    background-position: 0 -120px!important;
}
.ico_link_citation:hover{
    background-position: 0 -180px!important;
}


.ico_link_embed{
    background-position: -420px -120px!important;
}
.ico_link_embed:hover{
    background-position: -420px -180px!important;
}

.ico_link_galerie{
    background-position: -300px -360px!important;
}
.ico_link_galerie:hover{
    background-position: -300px -420px!important;
}

</style>
        <meta charset="<?php bloginfo('charset'); ?>">
        <title><?php wp_title(''); ?><?php
            if (wp_title('', false)) {
                echo ' :';
            }
            ?> <?php bloginfo('name'); ?></title>

        <link href="<?php bloginfo('url'); ?>favicon.ico" rel="shortcut icon">
        <link href="<?php echo get_template_directory_uri(); ?>/img/icons/touch.png" rel="apple-touch-icon-precomposed">
        <meta http-equiv="X-UA-Compatible" content="IE=edge">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <meta name="description" content="<?php bloginfo('description'); ?>">

        <link rel="stylesheet" type="text/css" href="<?php echo get_template_directory_uri(); ?>/css/bootstrap.css">
        <link rel="stylesheet" type="text/css" href="<?php echo get_template_directory_uri(); ?>/css/bootstrap-theme.css">
        <link rel="stylesheet" type="text/css" href="<?php echo get_template_directory_uri(); ?>/css/portfolio.css">
        <link rel="stylesheet" type="text/css" href="<?php echo get_template_directory_uri(); ?>/css/site.css">
        <link rel="stylesheet" type="text/css" href="<?php echo get_template_directory_uri(); ?>/css/cookieconsent.min.css">

        <?php wp_head(); ?>


        <script src="<?php echo get_template_directory_uri(); ?>/js/cookieconsent.min.js"></script>



        <script>
        window.addEventListener("load", function(){
        window.cookieconsent.initialise({
        "palette": {
            "popup": {
            "background": "#ffffff",
            "text": "#5c7291"
            },
            "button": {
            "background": "#0F5684",
            "text": "#ffffff"
            }
        },
        "content": {
            "message": "En poursuivant votre navigation sur ce site, vous acceptez l'utilisation de cookies sur votre ordinateur. ",
            "dismiss": "Accepter les cookies",
            "link": "En savoir plus",
            "href": "http://www.maine-et-loire.fr/mentions-legales"
        }
        })});
        </script>	
    		
        
        
        
        
        <script>
            // conditionizr.com
            // configure environment tests
            conditionizr.config({
                assets: '<?php echo get_template_directory_uri(); ?>',
                tests: {}
            });</script>
        <?php echo GenererFichiersCSS(); ?>
    </head>
    <body <?php body_class(); ?>>
    
    
    
    
<!-- AJOUT -->
	<dep49-header></dep49-header>
<!-- fin ajout -->
        <?php
        $current_numero = getCurrentNumero();
        $num_colors = get_option('numero_colors');
        $active_color = $num_colors[$current_numero->term_id];
        $bg = get_field("image_de_couverture", $current_numero->id_acf);
        $bg_cat = get_field("image_de_fond", "category_" . the_category_ID(false));
        $item = get_post($link["ID"]);
        $post_format = get_post_format($link["ID"]);
        $numMag = get_field("numerotation", $current_numero->id_acf);
//        get("coucou");
        if (!empty($bg_cat) && !is_home()) {
            // vars
            $bg_img = $bg_cat['url'];
            $bg_title = $bg_cat['alt'];
        } else {
            $bg_img = $bg['url'];
            $bg_title = $bg['alt'];
        }
//        if ($post_format == "aside" && !is_category()) {
//            $bg_cat = wp_get_attachment_image_src(get_post_thumbnail_id ( $post_ID ), 'full');
//            $bg_img = $bg_cat[0];
//
//        }

        $fonts = get_field("police", $current_numero->id_acf);
        //FONT TITLE
        if ($fonts) {
            wp_enqueue_style("dh_options_typography", "http://fonts.googleapis.com/css?family=$fonts", false, null, 'all');
            $fonts_css = "body, td, div, a, form, input, textarea, p{font-family:" . $fonts . " !important;}";
        }
        $fonts_title = get_field("police_titre", $current_numero->id_acf);
        if ($fonts_title) {
            wp_enqueue_style("dh_options_typography_title", "http://fonts.googleapis.com/css?family=$fonts_title", false, null, 'all');
            $fonts_css_title = ".home h2 p, .single h1.post-title, .page h2.color-current-numero, h1.category_color, h1.color-current-numero-bg, .encadre-titre h2, .h4.color-current-numero{font-family:" . $fonts_title . " !important;}";
        }
        ?>

        <style scoped>
            body{
                background: url(<?php echo $bg_img; ?>) no-repeat center fixed;
                -webkit-background-size: cover !important;
                background-size: cover !important;
                background-position: 0 50px !important;
            }
            <?php echo $fonts_css; ?>
            <?php echo $fonts_css_title; ?>
            nav.navbar{
                background-color:<?php echo $active_color; ?>;
            }
            span.count{
                background-color:<?php echo $active_color; ?>;
            }

            .color-current-numero{
                color: <?php echo $active_color; ?> !important;
            }
            .color-current-numero-bg{
                background-color: <?php echo $active_color; ?> !important;
            }
        </style>

        <?php
        // Get Arbo
        $tree_menu = dh_get_tree_menu_nav();

        // Get id current
        if (is_single()) {
            $id_item = get_the_ID(false);
        } else {
            $id_item = the_category_ID(false);
        }
        if (is_page()) {
            $id_item = $post->ID;
        }
        if (is_front_page()) {
            $id_item = 0;
        }

        // Set link
        if (!empty($tree_menu)) {
            $key = dh_find_key_array_by_value($tree_menu, $id_item);
            $max = count($tree_menu);
            
            $prev = $key - 1;
            if ($prev < 0) {
                $prev = $max - 1;
            }

            $next = $key + 1;
            if ($next > ($max - 1)) {
                $next = 0;
            }

            $link_prev = $tree_menu[$prev]['url'];
            $link_current = $tree_menu[$key]['url'];
            $link_next = $tree_menu[$next]['url'];
        }
        ?>
        <header>
            <nav class="navbar navbar-inverse navbar-static-top" role="navigation">
                <div class="navbar-header">
                    <button type="button" class="navbar-toggle collapsed pull-left" data-toggle="collapse" data-target="#main-navigation">
                        <span class="sr-only">Toggle navigation</span>
                        <span class="icon-bar"></span>
                        <span class="icon-bar"></span>
                        <span class="icon-bar"></span>
                    </button>
                </div>
                <div class="collapse navbar-collapse " id="main-navigation">
                    <?php wp_nav_menu(array('theme_location' => 'header-menu')); ?>
                </div>

                <div id="lang-navigation">
                    <?php wp_nav_menu(array('theme_location' => 'langmenu')); ?>
                </div>
            </nav>
        </header>
        <a href="#"><i class='ico-hide-menu' style="background-color:<?php echo $active_color; ?>" alt="Déplier/Replier le menu" title="Déplier/Replier le menu"></i></a>

        <div class="container-fluid">
            <div id="subnav" class="row">
                <ul class="ico-menu">
                    <li><?php get_template_part('searchform'); ?></li>
                    <li <?php
                    if (is_home() || is_front_page()) {
                        echo "style='border-bottom:5px solid " . $active_color . ";'";
                    };
                    ?> ><a href="<?php echo get_site_url(); ?>" class="ico-home" alt="home"></a></li>
                    <li><div class="ico-sommaire"><a href="<?php echo get_permalink(290); ?>">Sommaire</a></div></li>
                </ul>
                <div style="position:relative;overflow:hidden;width:960px;" class="container-scroll">
                    <?php wp_nav_menu(array('menu' => 'Sous-menu-' . $numMag)); ?>
                </div>
                <div class="scrollers">
                    <a tabindex="-1" class="fastclick back" href="#b" alt="Retour">Retour</a>
                    <a tabindex="-1" class="fastclick forward" href="#f" alt="En avant">En avant</a>
                </div>
            </div>
            <?php echo do_shortcode("[DH_SOCIAL_SHARE prev=" . $link_prev . " current=" . $link_current . " next=" . $link_next . "]"); ?>
        </div>

        <div class="container-fluid stop-fluid wrap-page" title="<?php echo $bg_title; ?>" >
